#include "builtin.h"
#include "submodule.h"
#include "strbuf.h"

/*
 * Exit non-zero if any of the submodule names given on the command line is
 * invalid. If no names are given, filter stdin to print only valid names
 * (which is primarily intended for testing).
 */
static int check_name(int argc, const char **argv, const char *prefix)
{
	if (argc > 1) {
		while (*++argv) {
			if (check_submodule_name(*argv) < 0)
				return 1;
		}
	} else {
		struct strbuf buf = STRBUF_INIT;
		while (strbuf_getline(&buf, stdin, '\n') != EOF) {
			if (!check_submodule_name(buf.buf))
				printf("%s\n", buf.buf);
		}
		strbuf_release(&buf);
	}
	return 0;
}

/*
 * Exit non-zero if the proposed submodule repository path is inside
 * another submodules' git dir.
 */
static int validate_git_dir(int argc, const char **argv, const char *prefix)
{
	char *sm_gitdir;

	if (argc != 3)
		usage("git submodule--helper validate-git-dir <path> <name>");
	sm_gitdir = xstrdup(argv[1]);
	if (validate_submodule_git_dir(sm_gitdir, argv[2]) < 0) {
		free(sm_gitdir);
		return 1;
	}
	free(sm_gitdir);
	return 0;
}

int cmd_submodule__helper(int argc, const char **argv, const char *prefix)
{
	if (argc < 2)
		usage("git submodule--helper <command>");
	if (!strcmp(argv[1], "check-name"))
		return check_name(argc - 1, argv + 1, prefix);
	if (!strcmp(argv[1], "validate-git-dir"))
		return validate_git_dir(argc - 1, argv + 1, prefix);
	die(_("'%s' is not a valid submodule--helper subcommand"), argv[1]);
}
